==> nextcloud-26.0.7p0.tgz: nextcloud/apps/password_policy/l10n/ar.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "انتهت صلاحية كلمة السر. رجاءً، استخدم طريقة \"نسيتُ كلمة السر\" لإعادة تعيينها",
    "Password must not have been used recently before." : "يجب ألاّ تكون كلمة السر قد أُستُخدمت مؤخراً.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "كلمة السر هذه ضمن الـ 1,000,000 كلمة الأكثر شيوعاً. رجاءً، إجعلها مُميّزة.",
    "Password is present in compromised password list. Please choose a different password." : "كلمة السر هذه ضمن قائمة كلمات السر المُتسرّبة. رجاءً، إختر كلمةً مخلتفةً",
    "Password needs to be at least %s characters long." : "يجب ألّا يقل طول كلمة السر عن %s حروف.",
    "Password needs to contain at least one numeric character." : "يجب أن تحوي كلمة السر خانة عددية و احدة على الأقل.",
    "Password needs to contain at least one special character." : "يجب أن تحوي كلمة السر حرفاً خاصاً واحداً على الأقل.",
    "Password needs to contain at least one lower and one upper case character." : "يحب أن تحوي كلمة السر حرفاً صغيراً واحداً و حرفاً كبيراً واحداً على الأقل.",
    "Password policy" : "سياسة كلمات السر",
    "Allows admins to configure a password policy" : "تُمكّن المشرفين من تهيئة سياسة كلمات السر",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "تُمكّن المشرفين من تعريف شروط مسبقة معينة لكلمة السر. مثلاً: فرض حد أدنى من الحروف للكلمة",
    "Minimum password length" : "الحد الأدنى لطول كلمة السر",
    "User password history" : "استعمل السجل التاريخي كلمات السر السابقة",
    "Number of days until user password expires" : "عدد الأيام المتبقية حتى انتهاء صلاحية كلمة سر المستخدم",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "عدد محاولات الدخول الفاشلة قبل قفل حساب المستخدم (0 تعني بدون حدود)",
    "Forbid common passwords" : "إمنع الكلمات الشائعة",
    "Enforce upper and lower case characters" : "إفرض استعمال الحروف الصغيرة و الكبيرة",
    "Enforce numeric characters" : "إفرض استعمال الخانات العددية",
    "Enforce special characters" : "إفرض استعمال الحروف الخاصة",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "تحقّق من كلمة السر المُعطاة في قائمة الكلمات المُتسرّبة على الموقع haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "يقوم هذا بتوليد مستخلص hash من كلمة السر ثم يرسل الـ 15 حرفاً الأولى منه إلى API الموقع haveibeenpwned.com؛ و ذلك لاسترجاع قائمة بكل المستخلصات في الموقع التي تبدأ بنفس بدايات المستخلص الحالي. بعدها يقوم بمقارنة المستخلص الحالي كاملاً بالمستخلصات المسترجعة من الموقع الخارجي.",
    "Unknown error" : "خطأ غير مُحدّد",
    "Minimal length has to be a non negative number" : "الحد الأدنى للطول يجب إلاً يكون أقل من صفر.",
    "History size has to be a non negative number" : "حجم السجل التاريخي يجب ألاّ يكون أقل من صفر",
    "Expiration days have to be a non negative number" : "عدد الأيام المتبقية حتى انتهاء الصلاحية يجب ألاّ يكون أقل من صفر",
    "Maximum login attempts have to be a non negative number" : "أقصى عدد لمحاولات الدخول يجب ألاّ يكون أقل من صفر",
    "Settings saved" : "تم حفظ الإعدادات",
    "Error while saving settings" : "خطأ أثناء حفظ الإعدادات",
    "Saved" : "تم الحفظ",
    "Error while saving" : "خطأ أثناء الحفظ"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-28.0.9.tgz: nextcloud/apps/password_policy/l10n/ar.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "انتهت صلاحية كلمة السر. رجاءً، استخدم طريقة \"نسيتُ كلمة السر\" لإعادة تعيينها",
    "Password must not have been used recently before." : "يجب ألاّ تكون كلمة السر قد أُستُخدمت مؤخراً.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "كلمة السر هذه ضمن الـ 1,000,000 كلمة الأكثر شيوعاً. رجاءً، إجعلها مُميّزة.",
    "Password is present in compromised password list. Please choose a different password." : "كلمة السر هذه ضمن قائمة كلمات السر المُتسرّبة. رجاءً، إختر كلمةً مخلتفةً",
    "Password needs to be at least %s characters long." : "يجب ألّا يقل طول كلمة السر عن %s حروف.",
    "Password needs to contain at least one numeric character." : "يجب أن تحوي كلمة السر خانة عددية و احدة على الأقل.",
    "Password needs to contain at least one special character." : "يجب أن تحوي كلمة السر حرفاً خاصاً واحداً على الأقل.",
    "Password needs to contain at least one lower and one upper case character." : "يحب أن تحوي كلمة السر حرفاً صغيراً واحداً و حرفاً كبيراً واحداً على الأقل.",
    "Password policy" : "سياسة كلمات السر",
    "Allows admins to configure a password policy" : "تُمكّن المشرفين من تهيئة سياسة كلمات السر",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "تُمكّن المشرفين من تعريف شروط مسبقة معينة لكلمة السر. مثلاً: فرض حد أدنى من الحروف للكلمة",
    "Minimum password length" : "الحد الأدنى لطول كلمة السر",
    "User password history" : "استعمل السجل التاريخي كلمات السر السابقة",
    "Number of days until user password expires" : "عدد الأيام المتبقية حتى انتهاء صلاحية كلمة سر المستخدم",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "عدد محاولات تسجيل الدخول قبل تعطيل حساب المستخدم حتى يتم اتخاذ الإجراء اليدوي. (0 بلا حدود)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "يرجى ملاحظة أن هذا الخيار يهدف إلى حماية الحسابات التي تعرضت للهجوم. يجب إعادة تمكين الحسابات المعطلة يدويّاً بواسطة الإدارة. المهاجمون الذين يحاولون تخمين كلمات مرور الحسابات سيتم حظر عنوان IP الخاص بهم بواسطة إجراءات الحماية من هجمات القوة الكاسحة بشكل مستقل عن هذا الإعداد.",
    "Forbid common passwords" : "إمنع الكلمات الشائعة",
    "Enforce upper and lower case characters" : "إفرض استعمال الحروف الصغيرة و الكبيرة",
    "Enforce numeric characters" : "إفرض استعمال الخانات العددية",
    "Enforce special characters" : "إفرض استعمال الحروف الخاصة",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "تحقّق من كلمة السر المُعطاة في قائمة الكلمات المُتسرّبة على الموقع haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "يقوم هذا بتوليد مستخلص hash من كلمة السر ثم يرسل الـ 15 حرفاً الأولى منه إلى API الموقع haveibeenpwned.com؛ و ذلك لاسترجاع قائمة بكل المستخلصات في الموقع التي تبدأ بنفس بدايات المستخلص الحالي. بعدها يقوم بمقارنة المستخلص الحالي كاملاً بالمستخلصات المسترجعة من الموقع الخارجي.",
    "Unknown error" : "خطأ غير مُحدّد",
    "Minimal length has to be a non negative number" : "الحد الأدنى للطول يجب إلاً يكون أقل من صفر.",
    "History size has to be a non negative number" : "حجم السجل التاريخي يجب ألاّ يكون أقل من صفر",
    "Expiration days have to be a non negative number" : "عدد الأيام المتبقية حتى انتهاء الصلاحية يجب ألاّ يكون أقل من صفر",
    "Maximum login attempts have to be a non negative number" : "أقصى عدد لمحاولات الدخول يجب ألاّ يكون أقل من صفر",
    "Settings saved" : "تم حفظ الإعدادات",
    "Error while saving settings" : "خطأ أثناء حفظ الإعدادات",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "يرجى ملاحظة أن هذا الخيار يهدف إلى حماية الحسابات التي تعرضت للهجوم. يجب إعادة تمكين الحسابات المعطلة يدويًا بواسطة الإدارة. المهاجمون الذين يحاولون تخمين كلمات مرور الحسابات سيتم حظر عنوان IP الخاص بهم بواسطة إجراءات الحماية من هجمات القوة الكاسحة بشكل مستقل عن هذا الإعداد."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
